@@ -3,9 +3,8 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Chromatic and diatonic musical ornamentation
 
-our $VERSION = '0.0204';
+our $VERSION = '0.0205';
 
-use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
 use MIDI::Simple ();
@@ -75,8 +74,8 @@ sub grace_note {
     print "Grace note: $grace_note\n" if $self->verbose;
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
-    my $y = $MIDI::Simple::Length{xn} * TICKS; # Sixtyfourth note
-    my $z = sprintf '%0.f', ($x - $y);
+    my $y = $MIDI::Simple::Length{yn} * TICKS; # Thirty-second note
+    my $z = sprintf '%0.f', $x - $y;
     print "Durations: $x, $y, $z\n" if $self->verbose;
 
     return [ ['d' . $y, $grace_note], ['d' . $z, $pitch] ];
@@ -86,6 +85,7 @@ sub grace_note {
 sub turn {
     my ($self, $duration, $pitch, $offset) = @_;
 
+    my $number = 4;
     $offset //= 1;
 
     my ($above, $below);
@@ -104,7 +104,7 @@ sub turn {
     print "Above/Below: $above / $below\n" if $self->verbose;
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
-    my $z = sprintf '%0.f', ($x / 4);
+    my $z = sprintf '%0.f', $x / $number;
     print "Durations: $x, $z\n" if $self->verbose;
     $z = 'd' . $z;
 
@@ -164,15 +164,15 @@ sub mordent {
     print "Alternate note: $alt\n" if $self->verbose;
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
-    my $z = sprintf '%0.f', $x / 4;
-    my $y = sprintf '%0.f', $x - (2 * $z);
-    print "Durations: $x, $z, $y\n" if $self->verbose;
-    $z = 'd' . $z;
+    my $y = sprintf '%0.f', $x / 4;
+    my $z = sprintf '%0.f', $x - (2 * $y);
+    print "Durations: $x, $y, $z\n" if $self->verbose;
     $y = 'd' . $y;
+    $z = 'd' . $z;
 
     my @mordent;
 
-    push @mordent, [$z, $pitch], [$z, $alt], [$y, $pitch];
+    push @mordent, [$y, $pitch], [$y, $alt], [$z, $pitch];
     print 'Mordent: ', ddc(\@mordent) if $self->verbose;
 
     return \@mordent;
@@ -192,7 +192,7 @@ Music::MelodicDevice::Ornamentation - Chromatic and diatonic musical ornamentati
 
 =head1 VERSION
 
-version 0.0204
+version 0.0205
 
 =head1 SYNOPSIS
 
@@ -200,17 +200,17 @@ version 0.0204
 
   # Chromatic
   my $md = Music::MelodicDevice::Ornamentation->new;
-  my $spec = $md->grace_note('qn', 'D5', 1); # [[xn D#5], [d90 D5]]
-  $spec = $md->turn('qn', 'D5', 1);          # [[sn D#5], [sn D5], [sn C#5], [sn D5]]
-  $spec = $md->trill('qn', 'D5', 2, 1);      # [[sn D#5], [sn D5], [sn D#5], [sn D5]]
-  $spec = $md->mordent('qn', 'D5', 1);       # [[yn D5], [yn D#5], [den D5]]
+  my $spec = $md->grace_note('qn', 'D5', 1);
+  $spec = $md->turn('qn', 'D5', 1);
+  $spec = $md->trill('qn', 'D5', 2, 1);
+  $spec = $md->mordent('qn', 'D5', 1);
 
   # Diatonic
   $md = Music::MelodicDevice::Ornamentation->new(scale_name => 'major');
-  $spec = $md->grace_note('qn', 'D5', 1); # [[xn E5], [d90 D5]]
-  $spec = $md->turn('qn', 'D5', 1);       # [[sn E5], [sn D5], [sn C5], [sn D5]]
-  $spec = $md->trill('qn', 'D5', 2, 1);   # [[sn E5], [sn D5], [sn E5], [sn D5]]
-  $spec = $md->mordent('qn', 'D5', 1);    # [[yn D5], [yn E5], [den D5]]
+  $spec = $md->grace_note('qn', 'D5', 1);
+  $spec = $md->turn('qn', 'D5', 1);
+  $spec = $md->trill('qn', 'D5', 2, 1);
+  $spec = $md->mordent('qn', 'D5', 1);
 
 =head1 DESCRIPTION
 
@@ -305,8 +305,6 @@ C<D5-E5-D5>.  A chromatic lower mordent would be C<D5-C#5-D5>.
 
 The F<t/01-methods.t> program in this distribution
 
-L<Carp>
-
 L<Data::Dumper::Compact>
 
 L<List::SomeUtils>
